@@ -7,5 +7,5 @@ from .fileinput import read_dataframe
 from .mdxinput import read_mdx
 from .credentials import get_credentials
 from .scriptutils import overwrite_protected_path
-from .fileoutput import SheetDataFrame, SheetDataFrameList, SheetFormatList, \
+from .fileoutput import SheetDataFrame, SheetDataFrameList, CellFormat, SheetFormat, SheetFormatList, \
     write_dataframe, write_dataframes
